fn download_extension(
binary: &str,
platform_key: &str,
version: &str,
metadata: &ReleaseBinary,
public_key: &PublicKey,
download_dir: &Path,
dry_run: bool,
) -> Result<Option<PathBuf>, InstallerError>Expand description
Downloads an extension binary, verifies its checksum and signature, and
returns the path to the verified file in download_dir.