pub(crate) struct Installer {
pub(crate) bin_dir: PathBuf,
}Expand description
Handles downloading, verifying, and placing extension binaries.
Fields
bin_dir: PathBufDirectory where extension binaries are installed.
Implementations
Sourceimpl Installer
impl Installer
pub(crate) fn from_env(exe_dir: Option<&Path>) -> Result<Self, InstallerError>
Sourcepub(crate) fn install(
&self,
extension: &str,
source: &InstallSource,
dry_run: bool,
quiet: bool,
) -> Result<InstallResult, InstallerError>
pub(crate) fn install( &self, extension: &str, source: &InstallSource, dry_run: bool, quiet: bool, ) -> Result<InstallResult, InstallerError>
Installs an extension and returns the installed version and description.
Sourcepub(crate) fn check_latest_version(
source: &InstallSource,
installed_version: Option<&str>,
) -> Result<Option<String>, InstallerError>
pub(crate) fn check_latest_version( source: &InstallSource, installed_version: Option<&str>, ) -> Result<Option<String>, InstallerError>
Checks if a newer version is available without installing.
Returns Some(latest_version) if the manifest version is strictly
newer, None if already up to date.
Sourcepub(crate) fn install_if_changed(
&self,
extension: &str,
source: &InstallSource,
installed_version: Option<&str>,
) -> Result<Option<InstallResult>, InstallerError>
pub(crate) fn install_if_changed( &self, extension: &str, source: &InstallSource, installed_version: Option<&str>, ) -> Result<Option<InstallResult>, InstallerError>
Installs an extension only if the manifest version is newer than
installed_version. Returns Some(result) if an update was
performed, None if already at the latest version.
Sourcefn install_inner(
&self,
extension: &str,
source: &InstallSource,
manifest: Option<ReleaseManifest>,
dry_run: bool,
quiet: bool,
) -> Result<InstallResult, InstallerError>
fn install_inner( &self, extension: &str, source: &InstallSource, manifest: Option<ReleaseManifest>, dry_run: bool, quiet: bool, ) -> Result<InstallResult, InstallerError>
Shared implementation for install and install_if_changed.
Sourcepub(crate) fn remove(
&self,
extension: &str,
dry_run: bool,
) -> Result<(), InstallerError>
pub(crate) fn remove( &self, extension: &str, dry_run: bool, ) -> Result<(), InstallerError>
Removes an extension’s binary and skill files.
Sourcefn resolve_install(
&self,
extension: &str,
source: &InstallSource,
pre_manifest: Option<ReleaseManifest>,
dry_run: bool,
quiet: bool,
) -> Result<ResolvedInstall, InstallerError>
fn resolve_install( &self, extension: &str, source: &InstallSource, pre_manifest: Option<ReleaseManifest>, dry_run: bool, quiet: bool, ) -> Result<ResolvedInstall, InstallerError>
Fetches the manifest, downloads the binary, and verifies checksums/signatures.
Sourcefn copy_binary(
&self,
resolved: &ResolvedInstall,
dry_run: bool,
quiet: bool,
) -> Result<(), InstallerError>
fn copy_binary( &self, resolved: &ResolvedInstall, dry_run: bool, quiet: bool, ) -> Result<(), InstallerError>
Atomically places the downloaded binary at its destination path.
Sourcefn remove_binary(
&self,
binary: &str,
dry_run: bool,
) -> Result<(), InstallerError>
fn remove_binary( &self, binary: &str, dry_run: bool, ) -> Result<(), InstallerError>
Deletes the named binary from bin_dir.
Sourcefn ensure_dirs(&self, dry_run: bool) -> Result<(), InstallerError>
fn ensure_dirs(&self, dry_run: bool) -> Result<(), InstallerError>
Creates bin_dir if it doesn’t exist and verifies it is writable.